@@ -27,7 +27,7 @@ mod typed_header;
 #[cfg_attr(docsrs, doc(cfg(feature = "websocket")))]
 pub mod websocket;
 
-use std::convert::{Infallible, TryInto};
+use std::convert::Infallible;
 
 pub use addr::{LocalAddr, RemoteAddr};
 use bytes::Bytes;
